:mod:`art.estimators.regression`
================================
.. automodule:: art.estimators.regression

Mixin Base Class Regressor
--------------------------
.. autoclass:: RegressorMixin
   :members:
   :special-members: __init__
   :inherited-members:
